from distutils.core import setup
setup(
  name = 'sunsketch',
  packages = ['sunsketch'], # this must be the same as the name above
  version = '0.2b',
  description = 'A simple Graphical display tool',
  author = 'Sun',
  author_email = 'xxsunxxrose@gmail.com',
  url = 'https://github.com/sunx2/sketch', # use the URL to the github repo
  keywords = ['print', 'beautiful', 'display','sun'], # arbitrary keywords
  classifiers = [],
)
